Arthroprod is a framework for computing with Absolute Relativity
| alpha | Simpler variadic generation of [Alpha] values.
This is the recommended way of creating raw alpha values if they are needed. Arguments
are u8s in the range 0-3.
|
| map | A simple helper for constructing hashmaps with less verbosity.
|
| mvec | Simpler variadic generation of [MultiVector] values.
Each argument must impliment the AR trait so that it is possible to convert them to
[Term]s, with the resulting MultiVector is the sum of all terms generated this way.
|
| term | Simpler variadic generation of [Term] values.
Terms created this way will have a default value (if one is not provided) and a
magnitude of 1. See alpha for more information on how the underlying [Alpha]
value is generated. It is also possible to specify a set of [Xi] values to use
for the term by providing a list of strings to use as the Xi symbolic values.
|